@@ -18,8 +18,10 @@ class ActivityLogHandler(MemoryHandler):
             }, data='\n'.join(buf))
 
             if resp.status_code != 200:
-                raise Exception(f"Failed to send logs to {self.endpoint}, status code: {resp.status_code}, response: {resp.text}")
+                print(f"Failed to send logs to {self.endpoint}, status code: {resp.status_code}, response: {resp.text}")
             self.buffer.clear()
+        except Exception as e:
+            print(f"Failed to send logs to {self.endpoint}, exception: {e}")
         finally:
             self.release()    
 
